Struct Ahb1fzr
#[repr(transparent)]pub struct Ahb1fzr(pub u32);Expand description
AHB1 peripheral freeze register
Tuple Fields
0: u32Implementations
impl Ahb1fzr
impl Ahb1fzr
pub const fn dbg_gpdma1_ch_stop(&self, n: usize) -> bool
pub const fn dbg_gpdma1_ch_stop(&self, n: usize) -> bool
GPDMA 1 channel y stop in CPU debug Write access can be protected by GPDMA_SECCFGR.SECy.
pub const fn set_dbg_gpdma1_ch_stop(&mut self, n: usize, val: bool)
pub const fn set_dbg_gpdma1_ch_stop(&mut self, n: usize, val: bool)
GPDMA 1 channel y stop in CPU debug Write access can be protected by GPDMA_SECCFGR.SECy.